@@ -1,27 +1,24 @@
 #import <AppAuth/AppAuth.h>
-#import <MediaLibraryKit/MediaLibraryKit.h>
 #import <MobileVLCKit/MobileVLCKit.h>
 #import <ObjectiveDropboxOfficial/ObjectiveDropboxOfficial.h>
 #import <VLCMediaLibraryKit/VLCMediaLibraryKit.h>
-#import <PAPasscode/PAPasscodeViewController.h>
 #import <XKKeychain/XKKeychain.h>
 #import "VLCExternalDisplayController.h"
 #import "UIColor+Presets.h"
-#import "VLCAboutViewController.h"
 #import "VLCAppDelegate.h"
 #import "VLCCloudServicesTableViewController.h"
 #import "VLCConstants.h"
+#import "VLCDownloadController.h"
 #import "VLCDownloadViewController.h"
 #import "VLCEmptyLibraryView.h"
 #import "VLCOpenNetworkStreamViewController.h"
+#import "VLCNetworkLoginViewController.h"
 #import "VLCPlaybackService+MediaLibrary.h"
 #import "VLCPlaybackNavigationController.h"
 #import "VLCPlayerDisplayController.h"
 #import "VLCServerListViewController.h"
-#import "VLCSettingsController.h"
+#import "VLCSlider.h"
 #import "VLCWiFiUploadTableViewCell.h"
-#import "VLCMovieViewController.h"
-#import "IASKSettingsTableViewController+Protected.h"
 #import "IASKSettingsReader.h"
 #import "IASKSwitch.h"
 #import "VLCHTTPUploaderController.h"
@@ -32,3 +29,9 @@
 #import "VLCMetadata.h"
 #import "VLCPlayerDisplayController.h"
 #import "NSString+SupportedMedia.h"
+#import "VLCFirstStepsViewController.h"
+#import "VLCPlaybackInfoSubtitlesFetcherViewController.h"
+#import "VLCDropboxConstants.h"
+#import "VLCStatusLabel.h"
+#import "VLCStoreController.h"
+#import "VLCThumbnailsCache.h"
